@@ -3,6 +3,7 @@ import requests
 
 from .auth import Authenticator
 from .v3.aws_integration import AwsIntegration
+from .v3.cert_auth import CertAuth
 from .v3.devices import Devices
 from .v3.dialects import Dialects
 from .v3.domains import Domains
@@ -41,6 +42,7 @@ class Coiote:
             self.url, self.session, auth=auth)
 
         self.aws_integration: AwsIntegration = self._make_module(AwsIntegration)
+        self.cert_auth: CertAuth = self._make_module(CertAuth)
         self.data_model: DataModel = self._make_module(DataModel)
         self.device_monitoring: DeviceMonitoring = self._make_module(DeviceMonitoring)
         self.devices: Devices = self._make_module(Devices)
